@@ -14,7 +14,8 @@ except ImportError:
 
 from . import PackageHandlerError
 from .utils import (ChDir, ask_yes_no, _get_package_hashes,
-                    _remove_hidden_stuff_mac)
+                    _remove_hidden_stuff_mac, _version_string_to_tuple,
+                    _version_tuple_to_string)
 
 log = logging.getLogger(__name__)
 
@@ -224,6 +225,7 @@ class PackageHandler(object):
         files = self.json_data['y_data']
         package_name = self._remove_ext(self._remove_version_number(
                                         package_name))
+        package_name = self._remove_platform(package_name)
         file_name = files.get(package_name, None)
         if file_name is None:
             log.info('Adding {} to file list'.format(package_name))
@@ -251,10 +253,15 @@ class PackageHandler(object):
                 info['patch_md5'] = patch_hash
                 info['patch_url'] = self.update_url + patch_name
 
-            if self.json_data['y_data'][name].get(version, None) == version:
-                self.json_data['y_data'][name] = {version: info}
+            log.debug('json version {}'.format(self.json_data['y_data'][name].get(version, None)))
+            if self.json_data['y_data'][name].get(version, None) is None:
+                log.debug('Adding new version to file')
+                self.json_data['y_data'][name][version] = {}
+                if self.json_data['y_data'][name][version].get('platform', None) is None:
+                    self.json_data['y_data'][name][version][p['platform']] = info
             else:
-                self.json_data['y_data'][name][version] = info
+                log.debug('Appending info data to version file')
+                self.json_data['y_data'][name][version][p['platform']] = info
 
     def _get_package_list(self):
         """Adds compatible packages to internal package manifest
@@ -273,22 +280,36 @@ class PackageHandler(object):
                 p_version = self._get_version_number(p)
                 p_name = self._remove_version_number(p)
                 p_name = self._remove_ext(p_name)
+                p_name = self._remove_platform(p_name)
                 _hash = _get_package_hashes(p)
+                platform = self._get_platform(p)
                 log.debug('Found new update {}'.format(p_name))
                 package_info = {'real_name': p,
                                 'name': p_name,
                                 'version': p_version,
                                 'filename': p,
-                                'md5': _hash}
-                path = self._check_make_patch(p_name, p_version)
+                                'md5': _hash,
+                                'platform': platform}
+                path = self._check_make_patch(p_name, p_version, platform)
                 if self.patch_support and path is not None:
-                    patch_name = self._make_patch(path[0], p, p_name, path[1])
+                    platform_patch_name = p_name + '-' + platform
+                    patch_name = self._make_patch(path[0], p,
+                                                  platform_patch_name, path[1])
                     patch_hash = _get_package_hashes(patch_name)
                     package_info['patch_name'] = patch_name
                     package_info['patch_md5'] = patch_hash
                 self.package_manifest.append(package_info)
 
-    def _check_make_patch(self, name, version):
+    def _get_platform(self, name):
+        platform_name = re.compile('[macnixw0-9]{3,5}').findall(name)[0]
+        log.debug('Platform name is: {}'.format(platform_name))
+        return platform_name
+
+    def _remove_platform(self, name):
+        name = re.sub('-[a-zA-Z0-9]{3,5}', '', name)
+        return name
+
+    def _check_make_patch(self, name, version, platform):
         """Check to see if previous version is available to make patch updates
         Also calculates patch number
 
@@ -304,6 +325,7 @@ class PackageHandler(object):
 
                 Tuple - (path to source file, patch number)
         """
+        src_file_path = None
         data_dir = os.path.join(self.files_dir, name)
         if os.path.exists(data_dir):
             with ChDir(data_dir):
@@ -313,9 +335,13 @@ class PackageHandler(object):
                 # if len(_files) < 2:
                     # return None
                 _files = _remove_hidden_stuff_mac(_files)
+                fixed_files = []
+                for f in _files:
+                    fixed_files.append(_version_string_to_tuple(f))
+                _files = fixed_files
                 if len(_files) < 1:
                     return None
-                highest_version = sorted(_files)[-1]
+                highest_version = _version_tuple_to_string(sorted(_files)[-1])
                 if highest_version > version:
                     return None
             version_dir = os.path.join(data_dir, highest_version)
@@ -324,9 +350,11 @@ class PackageHandler(object):
                 if len(files) == 0:
                     return None
                 for f in files:
-                    if highest_version in f:
+                    if highest_version in f and platform in f:
                         src_file_path = os.path.abspath(f)
                         break
+            if src_file_path is None:
+                return None
             return src_file_path, len(_files) + 1
 
     def _make_patch(self, src_path, dst_path, patch_name, patch_number):
