@@ -4,9 +4,11 @@ import bsdiff4
 import hashlib
 import logging
 import os
+import sys
 
 from .file_downloader import FileDownloader
-from .utils import ChDir
+from .utils import (ChDir, _version_string_to_tuple,
+                    _version_tuple_to_string, platform_)
 
 log = logging.getLogger(__name__)
 
@@ -36,6 +38,7 @@ class Patcher(object):
         self.patch_data = []
         self.patch_binary_data = []
         self.og_binary = None
+        self.plat = platform_
 
     def start(self):
         """Proxy method for :meth:`_verify_installed_binary`,
@@ -52,18 +55,18 @@ class Patcher(object):
         log.info('Starting patch updater...')
         # Check hash on installed binary to begin patching
         binary_check = self._verify_installed_binary()
-        if binary_check is False:
+        if not binary_check:
             log.warning('Binary check failed...')
             return False
         # Getting all required patch meta-data
         all_patches = self._get_all_patches(self.name)
-        if all_patches is False:
+        if not all_patches:
             log.warning('Cannot find all patches...')
             return False
 
         # Downloading and verify patches as i go
         download_check = self._download_verify_patches()
-        if download_check is False:
+        if not download_check:
             log.warning('Patch check failed...')
             return False
         self._apply_patches_in_memory()
@@ -119,22 +122,26 @@ class Patcher(object):
                 False - Failed to find all patches
         """
         needed_patches = []
-        versions = sorted(self.json_data['y_data'][name].keys())
+        versions = sorted(map(_version_string_to_tuple,
+                          self.json_data['y_data'][name].keys()))
+
         log.info('getting required patches')
         for i in versions:
-            if i > self.current_version:
+            if i > _version_string_to_tuple(self.current_version):
                 needed_patches.append(i)
 
         # Taking the list of needed patches and extracting the
         # patch data from it. If any loop fails, will return False
         # and start full binary update.
         log.info('Getting patch meta-data')
+
         for p in needed_patches:
             info = {}
+            v_num = _version_tuple_to_string(p)
             try:
-                info['patch_name'] = self.json_data['y_data'][name][p]['patch_name']
-                info['patch_url'] = self.json_data['y_data'][name][p]['patch_url']
-                info['patch_md5'] = self.json_data['y_data'][name][p]['patch_md5']
+                info['patch_name'] = self.json_data['y_data'][name][v_num][self.plat]['patch_name']
+                info['patch_url'] = self.json_data['y_data'][name][v_num][self.plat]['patch_url']
+                info['patch_md5'] = self.json_data['y_data'][name][v_num][self.plat]['patch_md5']
                 self.patch_data.append(info)
             except KeyError:
                 log.error('Missing required patch meta-data')
@@ -174,7 +181,7 @@ class Patcher(object):
     def _write_update_to_disk(self):
         """Writes updated binary to disk"""
         log.info('Writing update to disk')
-        filename = self.json_data['y_data'][self.name][self.highest_version]['filename']
+        filename = self.json_data['y_data'][self.name][self.highest_version][self.plat]['filename']
         with ChDir(self.update_folder):
             with open(filename, 'wb') as f:
                 f.write(self.new_binary)
@@ -193,8 +200,8 @@ class Patcher(object):
                 hash = dict['hash']
         """
         info = {}
-        info['filename'] = self.json_data['y_data'][name][version]['filename']
-        info['hash'] = self.json_data['y_data'][name][version]['md5']
+        info['filename'] = self.json_data['y_data'][name][version][self.plat]['filename']
+        info['hash'] = self.json_data['y_data'][name][version][self.plat]['md5']
         return info
 
     def _get_package_hashes(self, package):
